==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs(
    public val items:
    Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.builder()
            .items(
                items.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgsBuilder
internal constructor() {
    private var items:
        Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("viagdunmxywrqjpv")
    public suspend
    fun items(`value`: Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>) {
        this.items = value
    }

    @JvmName("vviwkmimlypwkovh")
    public suspend fun items(
        vararg
        values: Output<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>,
    ) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jtvflwjsqyaptgch")
    public suspend
    fun items(values: List<Output<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qsgjbtaohixuuleg")
    public suspend
    fun items(`value`: List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gvmihlncxrgprefq")
    public suspend
    fun items(argument: List<suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lumedgkfqufswuyv")
    public suspend fun items(
        vararg
        argument: suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ykxqfaxjkmgweipk")
    public suspend
    fun items(argument: suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend
                    { argument() }.build(),
            )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("kfmldcbmbkyoghsh")
    public suspend fun items(
        vararg
        values: FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs =
        FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs(
            items = items ?: throw PulumiNullFieldException("items"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs(
    public val items: Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs.builder()
            .items(
                items.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgsBuilder
internal constructor() {
    private var items:
        Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("hexxfgxergwtppsn")
    public suspend fun items(`value`: Output<List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>) {
        this.items = value
    }

    @JvmName("tbnvslxkludftlag")
    public suspend fun items(vararg values: Output<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("snrfsmbnwbygibxj")
    public suspend fun items(values: List<Output<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("iaoadevmwufrsjlw")
    public suspend fun items(`value`: List<FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cludjfyugnisxipr")
    public suspend fun items(argument: List<suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bkivgabtyxpykush")
    public suspend fun items(vararg argument: suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cxctkaulcqhbcixd")
    public suspend fun items(argument: suspend FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgsBuilder().applySuspend
                    { argument() }.build(),
            )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("ekdiodyvpdreglab")
    public suspend fun items(vararg values: FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesItemArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs =
        FieldLevelEncryptionConfigContentTypeProfileConfigContentTypeProfilesArgs(
            items = items ?: throw PulumiNullFieldException("items"),
        )
}
